/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 Vedran Grgo Vatavuk
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.vgv.xls.templates;

import com.vgv.xls.Props;
import com.vgv.xls.Style;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;

/**
 * Template to build custom styles.
 *
 *  <p>This is how you can use it:</p>
 *
 * <pre> class MyGoldStyle extends StyleTemplate {
 *      public MyGoldStyle(final Style style) {
 *          super(style
 *                  .with(
 *                      new ForegroundColor(IndexedColors.GOLD.getIndex()
 *                  )
 *                  .with(
 *                      new FillPattern(FillPatternType.SOLID_FOREGROUND)
 *              )
 *          ));
 *      }
 *  }
 * </pre>
 * @author Vedran Grgo Vatavuk (123vgv@gmail.com)
 * @version $Id$
 * @since 0.1
 */
public class StyleTemplate implements Style {

    /**
     * Origin style.
     */
    private final Style origin;

    /**
     * Ctor.
     * @param style Style
     */
    public StyleTemplate(final Style style) {
        this.origin = style;
    }

    @Override
    public final CellStyle attachTo(final Cell cell) {
        return this.origin.attachTo(cell);
    }

    @Override
    public final Style with(final Props<CellStyle> property) {
        return this.origin.with(property);
    }
}
